# eric7.Preferences.ConfigurationPages.NetworkProxyPage

Module implementing the Network configuration page.

### Global Attributes

None

### Classes

NetworkProxyPage | Class implementing the Network configuration page.

### Functions

create | Module function to create the configuration page.

## NetworkProxyPage

Class implementing the Network configuration page.

### Derived from

ConfigurationPageBase, Ui_NetworkProxyPage

### Class Attributes

None

### Class Methods

None

### Methods

NetworkProxyPage | Constructor
on_clearProxyPasswordsButton_clicked | Private slot to clear the saved HTTP(S) proxy passwords.
on_ftpProxyTypeCombo_currentIndexChanged | Private slot handling the selection of a proxy type.
save | Public slot to save the Networj configuration.

### Static Methods

None

#### NetworkProxyPage (Constructor)

NetworkProxyPage(configDialog)

Constructor

configDialog (ConfigurationDialog)
  reference to the configuration dialog

#### NetworkProxyPage.on_clearProxyPasswordsButton_clicked

on_clearProxyPasswordsButton_clicked()

Private slot to clear the saved HTTP(S) proxy passwords.

#### NetworkProxyPage.on_ftpProxyTypeCombo_currentIndexChanged

on_ftpProxyTypeCombo_currentIndexChanged(index)

Private slot handling the selection of a proxy type.

index (int)
  index of the selected item

#### NetworkProxyPage.save

save()

Public slot to save the Networj configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg (ConfigurationDialog)
  reference to the configuration dialog

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up